@@ -6,6 +6,8 @@
 """
 __docformat__ = "restructuredtext en"
 
+import json
+
 from warnings import warn
 
 from logilab.common.decorators import cached
@@ -13,6 +15,7 @@ from logilab.common.decorators import cached
 from cubicweb.selectors import is_instance
 from cubicweb.entities import AnyEntity, fetch_config
 from cubicweb.entities.adapters import ITreeAdapter
+from cubicweb.utils import CubicWebJsonEncoder
 
 class Project(AnyEntity):
     __regid__ = 'Project'
@@ -33,6 +36,13 @@ class Project(AnyEntity):
         """project item interface"""
         return self
 
+    def __json_encode__(self):
+        data = super(Project, self).__json_encode__()
+        data['versions'] = []
+        for version in self.reverse_version_of:
+            data['versions'].append(version)
+        return json.dumps(data, cls=CubicWebJsonEncoder)
+
     def latest_version(self, states=('published',), reverse=None):
         """returns the latest version(s) for the project in one of the given
         states.
