@@ -77,6 +77,9 @@ class ProjectModificationDateUpdateFromEntity(ProjectModificationDateUpdate):
     """Update modification_date from changes in an entity, when projects is
     not yet attached to entity."""
     def get_projecteid(self, entity):
+        if self.session.deleted_in_transaction(entity.eid):
+            # return an impossible eid so a request using this will be a no-op
+            return -1
         return entity.project.eid
 
 class VersionStatusChangeHook(hook.Hook):
@@ -164,7 +167,7 @@ class VersionPublishHook(hook.Hook):
         trinfo = self.entity
         version = trinfo.for_entity
         if version.publication_date is None:
-            version.set_attributes(publication_date=datetime.today())
+            version.cw_set(publication_date=datetime.today())
 
 
 # verification hooks ###########################################################
@@ -226,7 +229,7 @@ SKIP_O_RELS = localperms.SKIP_O_RELS
 
 # not necessary on:
 #
-# * "secondary" relations: todo_by, done_in, appeared_in, depends_on, uses
+# * "secondary" relations: assigned_to, done_in, appeared_in, depends_on, uses
 # * no propagation needed: wf_info_for
 #
 O_RELS |= set(('concerns', 'version_of', 'subproject_of'))
