@@ -97,12 +97,13 @@ class ProjectTicketsTab(EntityView):
 
     def tickets_rql(self):
         # prefetch everything we can for optimization
-        return ('Any T,TTI,TT,TP,TD,TDF,TCD,TMD,S,SN,V,VN,U,UL %s WHERE '
+        return ('Any T,TTI,TT,TP,TD,TDF,TCD,TMD,S,SN,V,VN,U,UL,TDU %s WHERE '
                 'T title TTI, T type TT, T priority TP, '
                 'T description TD, T description_format TDF, '
                 'T creation_date TCD, T modification_date TMD, '
                 'T in_state S, S name SN, '
                 'T done_in V?, V num VN, '
+                'T assigned_to TDU?, '
                 'T created_by U?, U login UL, '
                 'T concerns P, P eid %%(x)s'
                 % fixed_orderby_rql(self.SORT_DEFS))
@@ -133,7 +134,7 @@ class ProjectTicketsTable(tableview.EntityTableView):
     __regid__ = 'tracker.tickets.table'
     __select__ = is_instance('Ticket')
     columns = ['ticket', 'type', 'priority', 'in_state', 'done_in',
-               'creation_date', 'modification_date', 'created_by']
+               'creation_date', 'modification_date', 'created_by', 'assigned_to']
     column_renderers = {
         'ticket': tableview.MainEntityColRenderer(),
         'creation_date': RelativeDateColRenderer(header=_('created')),
@@ -144,9 +145,12 @@ class ProjectTicketsTable(tableview.EntityTableView):
                 renderfunc=lambda w,x: w(x.cw_adapt_to('IWorkflowable').printable_state)),
         'done_in': tableview.RelatedEntityColRenderer(
                 getrelated=lambda x: x.done_in and x.done_in[0] or None),
+        'assigned_to': tableview.RelatedEntityColRenderer(
+                getrelated=lambda x: x.assigned_to and x.assigned_to[0] or None),
         }
     layout_args = {
         'display_filter': 'top',
+        'hide_filter': False,
         'add_view_actions': True,
         }
 
