@@ -31,7 +31,7 @@ _pvs.tag_object_of(('*', 'appeared_in', 'Version'), 'hidden')
 _pvs.tag_subject_of(('Version', 'version_of', '*'), 'hidden')
 # in progress stable
 _pvs.tag_subject_of(('Version', 'depends_on', 'Version'), 'hidden')
-_pvs.tag_subject_of(('Version', 'todo_by', 'CWUser'), 'hidden')
+_pvs.tag_subject_of(('Version', 'assigned_to', 'CWUser'), 'hidden')
 # in title, progress stable
 for attr in ('num', 'starting_date', 'prevision_date'):
     _pvs.tag_attribute(('Version', attr), 'hidden')
@@ -286,8 +286,8 @@ class RssItemVersionView(xmlrss.RSSItemView):
         self.w(u'</item>\n')
 
     def render_user_in_charge(self, entity):
-        if entity.todo_by:
-            for user in entity.todo_by:
+        if entity.assigned_to:
+            for user in entity.assigned_to:
                 self._marker('dc:creator', user.name())
 
 
